
-- 商户百世快递费率

drop table if exists merch_rate_expr_best;

/*==============================================================*/
/* Table: merch_rate_expr_best                                  */
/*==============================================================*/
create table merch_rate_expr_best
(
   merch_best_rate_sn   varchar(22) not null  comment '商户百世费率编号',
   merch_sn             varchar(22) not null  comment '商户编号',
   biz_type             varchar(2)  comment 'e码头业务类型，【e_biz_type】，00:保税备货， 01:保税直营，02:保税展示补货，03:BC直购，10:保税展示跨境，11:保税展示一般贸易，99:全部',
   cal_formula_express  char(1)  comment '计算公式:0:重量;1:面单',
   expr_type            varchar(8)  comment '物流运送类型 ,00:普通',
   send_province        varchar(64)  comment '寄件地区 ',
   consignee_province   varchar(64)  comment '送达省份 ',
   consignee_city       varchar(64)  comment '送达城市',
   face_sheet_price     numeric(19,2)  comment '面单价(店提使用)',
   fst_gear_weight      numeric(19,2)  comment '一档重(<=1KG)',
   fst_gear_price       numeric(19,2)  comment '一档价(<=1KG)',
   snd_gear_weight      numeric(19,2)  comment '二档重(>1<=2KG)',
   snd_gear_price       numeric(19,2)  comment '二档价(>1<=2KG)',
   trd_gear_weight      numeric(19,2)  comment '三档重(>2<=3KG)',
   trd_gear_price       numeric(19,2)  comment '三档价(>2<=3KG)',
   four_gear_fst_weight numeric(19,2)  comment '四档首重(>3KG)',
   four_gear_fst_price  numeric(19,2)  comment '四档首重价(>3KG)',
   four_gear_snd_weight numeric(19,2)  comment '四档续重(>3KG)',
   four_gear_snd_price  numeric(19,2)  comment '四档续重价(>3KG)',
   is_valid             char(1)  comment '是否有效,0:有效，1:无效',
   remark               varchar(200)  comment '备注',
   creater_sn           varchar(22)  comment '创建人编号',
   create_time          varchar(19)  comment '创建时间,yyyy-MM-dd HH:mm:ss',
   moder_sn             varchar(22)  comment '修改人编号',
   mod_time             varchar(19)  comment '修改时间,yyyy-MM-dd HH:mm:ss',
   tstm                 timestamp default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP  comment '时间戳',
   primary key (merch_best_rate_sn)
);

alter table merch_rate_expr_best comment '商户百世费率';

/*==============================================================*/
/* Index: index_merch_biz_expr_sp_cp_cc                         */
/*==============================================================*/
create index index_merch_biz_expr_sp_cp_cc on merch_rate_expr_best
(
   merch_sn,
   biz_type,
   expr_type,
   send_province,
   consignee_province,
   consignee_city
);



drop table if exists merch_rate_expr_add_best;

/*==============================================================*/
/* Table: merch_rate_expr_add_best                              */
/*==============================================================*/
create table merch_rate_expr_add_best
(
   merch_best_add_rate_sn varchar(22) not null  comment '商户百世加收费费率编号',
   merch_sn             varchar(22) not null  comment '商户编号',
   biz_type             varchar(2)  comment 'e码头业务类型，【e_biz_type】，00:保税备货， 01:保税直营，02:保税展示补货，03:BC直购，10:保税展示跨境，11:保税展示一般贸易，99:全部',
   expr_type            varchar(8)  comment '物流运送类型 ,00:普通',
   consignee_province   varchar(64)  comment '送达省份 ',
   cal_type             char(1)  comment '计算方式:0:按重量;1:一口价',
   fst_weight           numeric(19,2)  comment '首重(<=),包含此重量',
   fst_price            numeric(19,2)  comment '首重价',
   snd_weight           numeric(19,2)  comment '续重',
   snd_price            numeric(19,2)  comment '续重价',
   unified_price        numeric(19,2)  comment '一口价',
   is_valid             char(1)  comment '是否有效,0:有效，1:无效',
   remark               varchar(200)  comment '备注',
   creater_sn           varchar(22)  comment '创建人编号',
   create_time          varchar(19)  comment '创建时间,yyyy-MM-dd HH:mm:ss',
   moder_sn             varchar(22)  comment '修改人编号',
   mod_time             varchar(19)  comment '修改时间,yyyy-MM-dd HH:mm:ss',
   tstm                 timestamp default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP  comment '时间戳',
   primary key (merch_best_add_rate_sn)
);

alter table merch_rate_expr_add_best comment '商户百世快递加收费率';


drop table if exists merch_rate_expr_insured_best;

/*==============================================================*/
/* Table: merch_rate_expr_insured_best                          */
/*==============================================================*/
create table merch_rate_expr_insured_best
(
   merch_best_insured_rate_sn varchar(22) not null  comment '商户百世保价费率编号',
   merch_sn             varchar(22)  comment '商户编号',
   biz_type             varchar(2)  comment 'e码头业务类型，【e_biz_type】，00:保税备货， 01:保税直营，02:保税展示补货，03:BC直购，10:保税展示跨境，11:保税展示一般贸易，99:全部',
   expr_type            varchar(8)  comment '物流运送类型，00：普通',
   consignee_province   varchar(64)  comment '送达省份 ',
   first_gear_min_value numeric(19,2)  comment '一档最小金额(元)',
   first_gear_max_value numeric(19,2)  comment '一档最大金额(<=)(元)',
   first_gear_insured_rate numeric(19,2)  comment '一档保价费(元)',
   two_gear_min_value   numeric(19,2)  comment '二档最小金额(元)',
   two_gear_max_value   numeric(19,2)  comment '二档最大金额(<=)(元)',
   two_gear_insured_rate numeric(19,2)  comment '二档保价费(元)',
   three_gear_min_value numeric(19,2)  comment '三档最小金额(元)',
   three_gear_max_value numeric(19,2)  comment '三档最大金额(<=)(元)',
   three_gear_insured_rate numeric(19,5)  comment '三档保价费率(%)',
   four_gear_min_value  numeric(19,2)  comment '四档最小金额(元)',
   four_gear_max_value  numeric(19,2)  comment '四档最大金额(<=)(元)',
   four_gear_insured_rate numeric(19,5)  comment '四档保价费率(%)',
   insured_minimum_charge numeric(19,2)  comment '保价最低收费（元）',
   is_valid             char(1)  comment '是否有效，0：有效、1：无效',
   remark               varchar(200)  comment '备注',
   creater_sn           varchar(22)  comment '创建人编号',
   create_time          varchar(19)  comment '创建时间,yyyy-MM-dd HH:mm:ss',
   moder_sn             varchar(22)  comment '修改人编号',
   mod_time             varchar(19)  comment '修改时间,yyyy-MM-dd HH:mm:ss',
   tstm                 timestamp default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP  comment '时间戳',
   primary key (merch_best_insured_rate_sn)
);

alter table merch_rate_expr_insured_best comment '商户百世保价费率';

-- 供应商百世快递费率

drop table if exists supplier_rate_expr_best;

/*==============================================================*/
/* Table: supplier_rate_expr_best                               */
/*==============================================================*/
create table supplier_rate_expr_best
(
   supp_best_rate_sn    varchar(22) not null  comment '供应商百世费率编号',
   comp_sn              varchar(22) not null  comment '公司编号',
   biz_type             varchar(2)  comment 'e码头业务类型，【e_biz_type】，00:保税备货， 01:保税直营，02:保税展示补货，03:BC直购，10:保税展示跨境，11:保税展示一般贸易，99:全部',
   expr_type            varchar(8)  comment '物流运送类型 ,00:普通',
   send_province        varchar(64)  comment '寄件地区 ',
   consignee_province   varchar(64)  comment '送达省份 ',
   consignee_city       varchar(64)  comment '送达城市',
   face_sheet_price     numeric(19,2)  comment '面单价(店提使用)',
   fst_gear_weight      numeric(19,2)  comment '一档重(<=1KG)',
   fst_gear_price       numeric(19,2)  comment '一档价(<=1KG)',
   snd_gear_weight      numeric(19,2)  comment '二档重(>1<=2KG)',
   snd_gear_price       numeric(19,2)  comment '二档价(>1<=2KG)',
   trd_gear_weight      numeric(19,2)  comment '三档重(>2<=3KG)',
   trd_gear_price       numeric(19,2)  comment '三档价(>2<=3KG)',
   four_gear_fst_weight numeric(19,2)  comment '四档首重(>3KG)',
   four_gear_fst_price  numeric(19,2)  comment '四档首重价(>3KG)',
   four_gear_snd_weight numeric(19,2)  comment '四档续重(>3KG)',
   four_gear_snd_price  numeric(19,2)  comment '四档续重价(>3KG)',
   is_valid             char(1)  comment '是否有效,0:有效，1:无效',
   remark               varchar(200)  comment '备注',
   creater_sn           varchar(22)  comment '创建人编号',
   create_time          varchar(19)  comment '创建时间,yyyy-MM-dd HH:mm:ss',
   moder_sn             varchar(22)  comment '修改人编号',
   mod_time             varchar(19)  comment '修改时间,yyyy-MM-dd HH:mm:ss',
   tstm                 timestamp default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP  comment '时间戳',
   primary key (supp_best_rate_sn)
);



/*==============================================================*/
/* Index: index_biz_expr_sp_cp_cc                               */
/*==============================================================*/
create index index_biz_expr_sp_cp_cc on supplier_rate_expr_best
(
   biz_type,
   expr_type,
   send_province,
   consignee_province,
   consignee_city
);


drop table if exists supplier_rate_expr_add_best;

/*==============================================================*/
/* Table: supplier_rate_expr_add_best                           */
/*==============================================================*/
create table supplier_rate_expr_add_best
(
   supp_best_add_rate_sn varchar(22) not null  comment '供应商百世加收费费率编号',
   biz_type             varchar(2)  comment 'e码头业务类型，【e_biz_type】，00:保税备货， 01:保税直营，02:保税展示补货，03:BC直购，10:保税展示跨境，11:保税展示一般贸易，99:全部',
   expr_type            varchar(8)  comment '物流运送类型 ,00:普通',
   consignee_province   varchar(64)  comment '送达省份 ',
   cal_type             char(1)  comment '计算方式:0:按重量;1:一口价',
   fst_weight           numeric(19,2)  comment '首重(<=),包含此重量',
   fst_price            numeric(19,2)  comment '首重价',
   snd_weight           numeric(19,2)  comment '续重',
   snd_price            numeric(19,2)  comment '续重价',
   unified_price        numeric(19,2)  comment '一口价',
   is_valid             char(1)  comment '是否有效,0:有效，1:无效',
   remark               varchar(200)  comment '备注',
   creater_sn           varchar(22)  comment '创建人编号',
   create_time          varchar(19)  comment '创建时间,yyyy-MM-dd HH:mm:ss',
   moder_sn             varchar(22)  comment '修改人编号',
   mod_time             varchar(19)  comment '修改时间,yyyy-MM-dd HH:mm:ss',
   tstm                 timestamp default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP  comment '时间戳',
   primary key (supp_best_add_rate_sn)
);

alter table supplier_rate_expr_add_best comment '供应商百世快递加收费率';



drop table if exists supplier_rate_expr_insured_best;

/*==============================================================*/
/* Table: supplier_rate_expr_insured_best                       */
/*==============================================================*/
create table supplier_rate_expr_insured_best
(
   supplier_best_insured_rate_sn varchar(22) not null  comment '供应商百世保价费率编号',
   biz_type             varchar(2)  comment 'e码头业务类型，【e_biz_type】，00:保税备货， 01:保税直营，02:保税展示补货，03:BC直购，10:保税展示跨境，11:保税展示一般贸易，99:全部',
   expr_type            varchar(8)  comment '物流运送类型，00：普通',
   consignee_province   varchar(64)  comment '送达省份 ',
   first_gear_min_value numeric(19,2)  comment '一档最小金额(元)',
   first_gear_max_value numeric(19,2)  comment '一档最大金额(<=)(元)',
   first_gear_insured_rate numeric(19,2)  comment '一档保价费(元)',
   two_gear_min_value   numeric(19,2)  comment '二档最小金额(元)',
   two_gear_max_value   numeric(19,2)  comment '二档最大金额(<=)(元)',
   two_gear_insured_rate numeric(19,2)  comment '二档保价费(元)',
   three_gear_min_value numeric(19,2)  comment '三档最小金额(元)',
   three_gear_max_value numeric(19,2)  comment '三档最大金额(<=)(元)',
   three_gear_insured_rate numeric(19,5)  comment '三档保价费率(%)',
   four_gear_min_value  numeric(19,2)  comment '四档最小金额(元)',
   four_gear_max_value  numeric(19,2)  comment '四档最大金额(<=)(元)',
   four_gear_insured_rate numeric(19,5)  comment '四档保价费率(%)',
   insured_minimum_charge numeric(19,2)  comment '保价最低收费（元）',
   is_valid             char(1)  comment '是否有效，0：有效、1：无效',
   remark               varchar(200)  comment '备注',
   creater_sn           varchar(22)  comment '创建人编号',
   create_time          varchar(19)  comment '创建时间,yyyy-MM-dd HH:mm:ss',
   moder_sn             varchar(22)  comment '修改人编号',
   mod_time             varchar(19)  comment '修改时间,yyyy-MM-dd HH:mm:ss',
   tstm                 timestamp default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP  comment '时间戳',
   primary key (supplier_best_insured_rate_sn)
);

alter table supplier_rate_expr_insured_best comment '供应商百世保价费率';



-- 数据增加

INSERT INTO cps_pt.sys_dict_items (item_sn, dict_code, dict_itme, dict_item_name, dict_ord, is_valid, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('diit860458185288159232', 'expFlag', 'best', '百世快递', 7, '0', 'user000000000000000001', '2021-07-02 09:53:37', null, '2021-07-02 09:53:37', '2021-07-02 09:53:37');

-- 菜单

INSERT INTO cps_pt.sys_menu (menu_sn, menu_name, menu_ename, parent_menu_sn, root_menu_sn, menu_tier, menu_url, menu_order, menu_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('menu000000000002021071', '百世费率', 'merch_rate_expr_best', 'menu000000000002002000', 'menu000000000002000000', '3', '#/views/merchant/merchrate/merch-rate-expr-best.html', '311', '0', null, null, null, 'user000000000000000001', '2017-12-11 15:23:30', 'user000000000000000001', '2017-12-11 15:23:30', '2019-03-07 11:44:09');
INSERT INTO cps_pt.sys_menu (menu_sn, menu_name, menu_ename, parent_menu_sn, root_menu_sn, menu_tier, menu_url, menu_order, menu_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('menu000000000002021072', '百世快递保价费率', 'merch_rate_expr_insured_best', 'menu000000000002002000', 'null', '3', '#/views/merchant/merchrate/merch-rate-expr-insured-best.html', '318', '0', null, null, null, 'user000000000000000001', '2020-01-06 10:00:00', 'user000000000000000001', '2020-01-06 10:00:00', '2020-01-06 10:00:00');
INSERT INTO cps_pt.sys_menu (menu_sn, menu_name, menu_ename, parent_menu_sn, root_menu_sn, menu_tier, menu_url, menu_order, menu_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('menu000000000002021073', '百世快递加收费率', 'merch_rate_expr_add_best', 'menu000000000002002000', 'menu000000000002000000', '3', '#/views/merchant/merchrate/merch-rate-expr-add-best.html', '315', '0', null, null, null, 'user000000000000000001', '2019-05-22 09:26:12', 'user000000000000000001', '2019-05-22 09:26:12', '2019-05-22 09:26:13');
INSERT INTO cps_pt.sys_menu (menu_sn, menu_name, menu_ename, parent_menu_sn, root_menu_sn, menu_tier, menu_url, menu_order, menu_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('menu000000000002021074', '百世费率', 'supplier_rate_expr_best', 'menu000000000002004000', 'menu000000000002000000', '3', '#/views/merchant/supplierrate/supplier-rate-expr-best.html', '504', '0', null, null, null, 'user000000000000000001', '2017-12-11 15:23:30', 'user000000000000000001', '2017-12-11 15:23:30', '2019-03-07 11:44:23');
INSERT INTO cps_pt.sys_menu (menu_sn, menu_name, menu_ename, parent_menu_sn, root_menu_sn, menu_tier, menu_url, menu_order, menu_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('menu000000000002021075', '百世快递保价费率', 'supplier_rate_expr_insured_best', 'menu000000000002004000', 'null', '3', '#/views/merchant/supplierrate/supplier-rate-expr-insured-best.html', '511', '0', null, null, null, 'user000000000000000001', '2020-01-06 10:00:00', 'user000000000000000001', '2020-01-06 10:00:00', '2020-01-06 10:00:00');
INSERT INTO cps_pt.sys_menu (menu_sn, menu_name, menu_ename, parent_menu_sn, root_menu_sn, menu_tier, menu_url, menu_order, menu_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('menu000000000002021076', '百世快递加收费率', 'supp_rate_expr_add_best', 'menu000000000002004000', 'menu000000000002000000', '3', '#/views/merchant/supplierrate/supplier-rate-expr-add-best.html', '508', '0', null, null, null, 'user000000000000000001', '2019-05-22 09:27:08', 'user000000000000000001', '2019-05-22 09:27:08', '2019-05-22 09:27:53');

-- 菜单权限
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092325536612352', '新增', 'add', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092362178052096', '修改', 'upd', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092398886600704', '删除', 'del', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595184952213504', '导入模板下载', 'template', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595233899741184', '导入', 'importExcel', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());

INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092325536612352', '新增', 'add', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092362178052096', '修改', 'upd', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092398886600704', '删除', 'del', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595184952213504', '导入模板下载', 'template', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595233899741184', '导入', 'importExcel', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());

INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092325536612352', '新增', 'add', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092362178052096', '修改', 'upd', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092398886600704', '删除', 'del', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595184952213504', '导入模板下载', 'template', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595233899741184', '导入', 'importExcel', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());

INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092325536612352', '新增', 'add', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092362178052096', '修改', 'upd', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092398886600704', '删除', 'del', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595184952213504', '导入模板下载', 'template', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595233899741184', '导入', 'importExcel', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());

INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092325536612352', '新增', 'add', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092362178052096', '修改', 'upd', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092398886600704', '删除', 'del', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595184952213504', '导入模板下载', 'template', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595233899741184', '导入', 'importExcel', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());

INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092325536612352', '新增', 'add', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092362178052096', '修改', 'upd', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func580092398886600704', '删除', 'del', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595184952213504', '导入模板下载', 'template', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('func558595233899741184', '导入', 'importExcel', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', now(), 'user000000000000000001', now(), now());

INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func172733381458309820', '导入', 'importExcel', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:43:01', 'user000000000000000001', '2021-07-05 14:43:01', '2021-07-05 14:43:01');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func287107972416196000', '导入模板下载', 'template', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:43:01', 'user000000000000000001', '2021-07-05 14:43:01', '2021-07-05 14:43:01');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func387602169427650200', '删除', 'del', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:43:01', 'user000000000000000001', '2021-07-05 14:43:01', '2021-07-05 14:43:01');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func399078676289952060', '新增', 'add', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:43:00', 'user000000000000000001', '2021-07-05 14:43:00', '2021-07-05 14:43:00');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func516967634127445200', '修改', 'upd', 'menu000000000002021076', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:43:00', 'user000000000000000001', '2021-07-05 14:43:00', '2021-07-05 14:43:00');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func745895835893131600', '删除', 'del', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:43:00', 'user000000000000000001', '2021-07-05 14:43:00', '2021-07-05 14:43:00');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func759475258327531900', '导入', 'importExcel', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:43:00', 'user000000000000000001', '2021-07-05 14:43:00', '2021-07-05 14:43:00');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func799432547669329300', '导入模板下载', 'template', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:43:00', 'user000000000000000001', '2021-07-05 14:43:00', '2021-07-05 14:43:00');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func343348886485536500', '修改', 'upd', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:59', 'user000000000000000001', '2021-07-05 14:42:59', '2021-07-05 14:42:59');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func536021838277598660', '导入', 'importExcel', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:59', 'user000000000000000001', '2021-07-05 14:42:59', '2021-07-05 14:42:59');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func590282874731610400', '新增', 'add', 'menu000000000002021075', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:59', 'user000000000000000001', '2021-07-05 14:42:59', '2021-07-05 14:42:59');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func634661209801827800', '修改', 'upd', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:59', 'user000000000000000001', '2021-07-05 14:42:59', '2021-07-05 14:42:59');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func663275448105554600', '导入模板下载', 'template', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:59', 'user000000000000000001', '2021-07-05 14:42:59', '2021-07-05 14:42:59');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func893451809970151400', '删除', 'del', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:59', 'user000000000000000001', '2021-07-05 14:42:59', '2021-07-05 14:42:59');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func269117522304055780', '删除', 'del', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:58', 'user000000000000000001', '2021-07-05 14:42:58', '2021-07-05 14:42:58');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func726618088899755900', '新增', 'add', 'menu000000000002021074', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:58', 'user000000000000000001', '2021-07-05 14:42:58', '2021-07-05 14:42:58');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func734699125340859500', '导入模板下载', 'template', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:58', 'user000000000000000001', '2021-07-05 14:42:58', '2021-07-05 14:42:58');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func770296171279899900', '修改', 'upd', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:58', 'user000000000000000001', '2021-07-05 14:42:58', '2021-07-05 14:42:58');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func966143087452410900', '导入', 'importExcel', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:58', 'user000000000000000001', '2021-07-05 14:42:58', '2021-07-05 14:42:58');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func141789825672088030', '删除', 'del', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:57', 'user000000000000000001', '2021-07-05 14:42:57', '2021-07-05 14:42:57');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func261051037685061860', '新增', 'add', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:57', 'user000000000000000001', '2021-07-05 14:42:57', '2021-07-05 14:42:57');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func344547597546640400', '导入', 'importExcel', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:57', 'user000000000000000001', '2021-07-05 14:42:57', '2021-07-05 14:42:57');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func353983409380524800', '导入模板下载', 'template', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:57', 'user000000000000000001', '2021-07-05 14:42:57', '2021-07-05 14:42:57');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func384988582213398600', '修改', 'upd', 'menu000000000002021072', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:57', 'user000000000000000001', '2021-07-05 14:42:57', '2021-07-05 14:42:57');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func560787787251908100', '新增', 'add', 'menu000000000002021073', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:57', 'user000000000000000001', '2021-07-05 14:42:57', '2021-07-05 14:42:57');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func135353348809623490', '导入模板下载', 'template', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:56', 'user000000000000000001', '2021-07-05 14:42:56', '2021-07-05 14:42:56');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func501114853472555840', '删除', 'del', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:56', 'user000000000000000001', '2021-07-05 14:42:56', '2021-07-05 14:42:56');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func756740315404478700', '修改', 'upd', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:56', 'user000000000000000001', '2021-07-05 14:42:56', '2021-07-05 14:42:56');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func873422211290730400', '导入', 'importExcel', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:56', 'user000000000000000001', '2021-07-05 14:42:56', '2021-07-05 14:42:56');
INSERT INTO cps_pt.sys_function (func_sn, func_name, func_ename, menu_sn, func_status, remarks, deleter_sn, delete_time, creater_sn, create_time, moder_sn, mod_time, tstm) VALUES ('func460862250403372800', '新增', 'add', 'menu000000000002021071', '0', null, null, null, 'user000000000000000001', '2021-07-05 14:42:55', 'user000000000000000001', '2021-07-05 14:42:55', '2021-07-05 14:42:55');

-- 数据字典
INSERT INTO cps_pt.sys_dictionary (dict_sn, dict_code, dict_name, maintain_flag, dict_type, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('dict861630219573538816', 'exprTypeBest', '物流运送类型-百世', '0', '0', 'user000000000000000001', '2021-07-05 15:30:52', 'user000000000000000001', '2021-07-05 15:30:52', '2021-07-05 15:30:49');
INSERT INTO cps_pt.sys_dict_items (item_sn, dict_code, dict_itme, dict_item_name, dict_ord, is_valid, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('diit861630547316453376', 'exprTypeBest', '70', '普通', null, '0', 'user000000000000000001', '2021-07-05 15:32:10', null, '2021-07-05 15:32:10', '2021-07-05 15:32:07');
INSERT INTO cps_pt.sys_dict_items (item_sn, dict_code, dict_itme, dict_item_name, dict_ord, is_valid, creater_sn, create_time, moder_sn, mod_time, tstm) 
VALUES ('diit861975877304332288', 'expFlag', 'best', '百世快递', 7, '0', 'user000000000000000001', '2021-07-06 14:24:23', 'user000000000000000001', '2021-07-06 14:24:30', '2021-07-06 14:24:27');

alter table tmp_cp_data_order_pkg modify remark varchar(512) null comment '备注';